/// <reference types="node" />
import { API, DynamicPlatformPlugin, Logger, PlatformAccessory, PlatformConfig, Service, Characteristic } from 'homebridge';
import { LaCrosseDTAccessoryBase } from './accessories/LaCrosseDTAccessoryBase';
/**
 * HomebridgePlatform
 * This class is the main constructor for your plugin, this is where you should
 * parse the user config and discover/register accessories with Homebridge.
 */
export declare class JeeLinkPlugin implements DynamicPlatformPlugin {
    readonly log: Logger;
    readonly config: PlatformConfig;
    readonly api: API;
    readonly Service: typeof Service;
    readonly Characteristic: typeof Characteristic;
    private readonly LaCrosseDTHParser;
    private pipe;
    readonly accessories: LaCrosseDTAccessoryBase[];
    constructor(log: Logger, config: PlatformConfig, api: API);
    /**
     * This function is invoked when homebridge restores cached accessories from disk at startup.
     * It should be used to setup event handlers for characteristics and update respective values.
     */
    configureAccessory(accessory: PlatformAccessory): void;
    createObjctForName(name: string): any;
    createObjctForType(type: number): any;
    parseData(data: Buffer): void;
    /**
     * The service is going to shut down.
     * Wee need to stop the serial port
     */
    shutdown(): void;
    /**
     * This is an example method showing how to register discovered accessories.
     * Accessories must only be registered once, previously created accessories
     * must not be registered again to prevent "duplicate UUID" errors.
     */
    discoverDevices(): void;
    getName(deviceID: string): any;
    getAccessory(deviceID: string): LaCrosseDTAccessoryBase | null;
    createAccessory(instanceType: typeof LaCrosseDTAccessoryBase, id: number, deviceType: number): LaCrosseDTAccessoryBase | null;
    getAccessoryWithId(uuid: string): LaCrosseDTAccessoryBase | null;
}
//# sourceMappingURL=platform.d.ts.map